@@ -40,7 +40,7 @@ class epHandler:
             return self.ep_list
 
         if not self.movie_id:
-            r = requests.get(self.entry.category_url)
+            r = requests.get(self.entry.category_url, timeout=2)
             self.movie_id = re.search(
                 r'<input.+?value="(\d+)" id="movie_id"', r.text
             ).group(1)
@@ -48,6 +48,7 @@ class epHandler:
         res = requests.get(
             "https://ajax.gogo-load.com/ajax/load-list-episode",
             params={"ep_start": 0, "ep_end": 9999, "id": self.movie_id},
+            timeout=2,
         )
 
         response_err(res, res.url)
@@ -80,7 +81,7 @@ class epHandler:
         filtered = list(filter(lambda x: x["ep"] == str(self.entry.ep), ep_list))
 
         if not filtered:
-            error(f"Episode {self.entry.ep} does not exsist.")
+            error(f"Episode {self.entry.ep} does not exist.")
             sys.exit()
 
         self.entry.ep_url = filtered[0]["link"]
@@ -139,8 +140,8 @@ class epHandler:
     def _validate_ep(self, ep: str):
         """
         See if Episode is in episode list.
-        Pass a arg to special to accept this
-        charachter even though it is not in the episode list.
+        Pass an arg to special to accept this
+        character even though it is not in the episode list.
         """
 
         ep_list = self._load_eps_list()
@@ -151,8 +152,8 @@ class epHandler:
 
     def pick_ep(self):
         """
-        Cli function to pick a episode from 1 to
-        the latest avalible.
+        Cli function to pick an episode from 1 to
+        the latest available.
         """
 
         self.get_latest()
@@ -174,8 +175,8 @@ class epHandler:
 
     def pick_ep_seasonal(self):
         """
-        Cli function to pick a episode from 0 to
-        the latest avalible.
+        Cli function to pick an episode from 0 to
+        the latest available.
         """
 
         self.get_latest()
